@@ -1,5 +1,5 @@
 """
-codicefiscale - Python library for Italian fiscal code (codicefiscale)
+Python library for Italian fiscal code
 
 codicefiscale is a Python library for working with Italian fiscal code numbers
 officially known as Italy's Codice Fiscale.
@@ -22,7 +22,7 @@ License along with this library; if not, write to the Free Software
 Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 """
 
-__version__ = '0.2'
+__version__ = '0.4'
 __author__ = "Emanuele Rocca"
 
 import re
@@ -30,7 +30,7 @@ import sets
 import string
 
 __VOWELS = [ 'A', 'E', 'I', 'O', 'U' ]
-__CONSONANTS = list(sets.Set(list(string.uppercase)).difference(__VOWELS))
+__CONSONANTS = list(sets.Set(list(string.ascii_uppercase)).difference(__VOWELS))
 
 MONTHSCODE = [ 'A', 'B', 'C', 'D', 'E', 'H', 'L', 'M', 'P', 'R', 'S', 'T' ]
 
@@ -38,6 +38,7 @@ PATTERN = "^[A-Z]{6}[0-9]{2}([A-E]|[HLMPRST])[0-9]{2}[A-Z][0-9]{3}[A-Z]$"
 
 def isvalid(code):
     """``isvalid(code) -> bool``
+
     This function checks if the given fiscal code is syntactically valid.
 
     eg: isvalid('RCCMNL83S18D969H') -> True
@@ -56,7 +57,7 @@ def __common_triplet(input_string, consonants, vowels):
         stopat = 2 
 
     while len(output) < stopat:
-        output += vowels.pop()
+        output += vowels.pop(0)
     
     if len(output) == 2:
         output += 'X'
@@ -91,8 +92,9 @@ def __name_triplet(input_string):
 
 def control_code(input_string):
     """``control_code(input_string) -> int``
-    Computes the control code for the given input_string string. The expected input_string is
-    the first 15 characters of a fiscal code.
+
+    Computes the control code for the given input_string string. The expected
+    input_string is the first 15 characters of a fiscal code.
 
     eg: control_code('RCCMNL83S18D969') -> 'H'"""
     assert len(input_string) == 15
@@ -103,7 +105,7 @@ def control_code(input_string):
     for idx, char in enumerate(string.digits):
         even_controlcode[char] = idx
 
-    for idx, char in enumerate(string.uppercase):
+    for idx, char in enumerate(string.ascii_uppercase):
         even_controlcode[char] = idx
 
     values = [ 1, 0, 5, 7, 9, 13, 15, 17, 19, 21, 2, 4, 18, 20, 11, 3, 6, 8,
@@ -114,7 +116,7 @@ def control_code(input_string):
     for idx, char in enumerate(string.digits):
         odd_controlcode[char] = values[idx]
 
-    for idx, char in enumerate(string.uppercase):
+    for idx, char in enumerate(string.ascii_uppercase):
         odd_controlcode[char] = values[idx]
 
     # computing the code
@@ -125,10 +127,11 @@ def control_code(input_string):
         else:
             code += even_controlcode[char]
     
-    return string.uppercase[code % 26]
+    return string.ascii_uppercase[code % 26]
 
 def build(surname, name, birthday, sex, municipality):
     """``build(surname, name, birthday, sex, municipality) -> string``
+
     Computes the fiscal code for the given person data.
 
     eg: build('Rocca', 'Emanuele', datetime.datetime(1983, 11, 18), 'M', 'D969') 
@@ -159,6 +162,7 @@ def build(surname, name, birthday, sex, municipality):
 # info from fiscal code 
 def get_birthday(code):
     """``get_birthday(code) -> string``
+
     The birthday of the person whose fiscal code is 'code', in the format
     DD-MM-YY. 
 
@@ -179,6 +183,7 @@ def get_birthday(code):
 
 def get_sex(code):
     """``get_sex(code) -> string``
+
     The sex of the person whose fiscal code is 'code'.
 
     eg: sex('RCCMNL83S18D969H') -> 'M'
